@@ -1,16 +1,11 @@
 from dataverk import utils
-from dataverk.dataverk_context import DataverkContext
 from dataverk.dataverk import Dataverk
 from dataverk.dataverk import Dataverk as Client
-from dataverk.utils import anonymization
 from dataverk.datapackage import Datapackage
 
-
-__all__ = ['anonymization',
-           'connectors',
+__all__ = ['connectors',
            'utils',
            'Datapackage',
            'Client',
-           'Dataverk',
-           'DataverkContext',
+           'Dataverk'
            ]
